@@ -5,19 +5,19 @@ namespace Lcobucci\JWT\Tests\Signer\Ecdsa;
 
 use Lcobucci\JWT\Signer\Ecdsa;
 use Lcobucci\JWT\Signer\Ecdsa\Sha512;
+use Lcobucci\JWT\Signer\InvalidKeyProvided;
 use Lcobucci\JWT\Signer\Key;
+use Lcobucci\JWT\Signer\OpenSSL;
+use PHPUnit\Framework\Attributes as PHPUnit;
 
 use const OPENSSL_ALGO_SHA512;
 
-/**
- * @covers \Lcobucci\JWT\Signer\Ecdsa\MultibyteStringConverter
- * @covers \Lcobucci\JWT\Signer\Ecdsa\Sha512
- * @covers \Lcobucci\JWT\Signer\Ecdsa
- * @covers \Lcobucci\JWT\Signer\OpenSSL
- * @covers \Lcobucci\JWT\Signer\InvalidKeyProvided
- *
- * @uses \Lcobucci\JWT\Signer\Key\InMemory
- */
+#[PHPUnit\CoversClass(Ecdsa::class)]
+#[PHPUnit\CoversClass(Ecdsa\MultibyteStringConverter::class)]
+#[PHPUnit\CoversClass(Ecdsa\Sha512::class)]
+#[PHPUnit\CoversClass(OpenSSL::class)]
+#[PHPUnit\CoversClass(InvalidKeyProvided::class)]
+#[PHPUnit\UsesClass(Key\InMemory::class)]
 final class Sha512Test extends EcdsaTestCase
 {
     protected function algorithm(): Ecdsa
